summaryrefslogtreecommitdiffstats
path: root/glances/main.py
diff options
context:
space:
mode:
authornicolargo <nicolas@nicolargo.com>2021-05-23 19:17:14 +0200
committernicolargo <nicolas@nicolargo.com>2021-05-23 19:17:14 +0200
commit0417762d9620fc31ceb15705117c2506c0319cfb (patch)
tree1b63667a5f307533e6edb722e0869f69cf6e493d /glances/main.py
parentabb97d5286af5893b2ae69eb7c9c2f1ffc8bf61b (diff)
Update documentation
Diffstat (limited to 'glances/main.py')
-rw-r--r--glances/main.py10
1 files changed, 6 insertions, 4 deletions
diff --git a/glances/main.py b/glances/main.py
index 77c9471f..88b27038 100644
--- a/glances/main.py
+++ b/glances/main.py
@@ -2,7 +2,7 @@
#
# This file is part of Glances.
#
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
#
# Glances is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
@@ -67,7 +67,7 @@ Examples of use:
Monitor local machine and export stats to a CSV file (standalone mode):
$ glances --export csv --export-csv-file /tmp/glances.csv
Monitor local machine and export stats to a InfluxDB server with 5s refresh time (standalone mode):
$ glances -t 5 --export influxdb
Start a Glances XML-RPC server (server mode):
@@ -206,11 +206,13 @@ Examples of use:
parser.add_argument('--snmp-force', action='store_true', default=False,
dest='snmp_force', help='force SNMP mode')
parser.add_argument('-t', '--time', default=self.DEFAULT_REFRESH_TIME, type=float,
- dest='time', help='set refresh time in seconds [default: {} sec]'.format(self.DEFAULT_REFRESH_TIME))
+ dest='time', help='set minumum refresh rate in seconds [default: {} sec]'.format(
+ self.DEFAULT_REFRESH_TIME))
parser.add_argument('-w', '--webserver', action='store_true', default=False,
dest='webserver', help='run Glances in web server mode (bottle needed)')
parser.add_argument('--cached-time', default=self.cached_time, type=int,
- dest='cached_time', help='set the server cache time [default: {} sec]'.format(self.cached_time))
+ dest='cached_time', help='set the server cache time [default: {} sec]'.format(
+ self.cached_time))
parser.add_argument('--open-web-browser', action='store_true', default=False,
dest='open_web_browser', help='try to open the Web UI in the default Web browser')
# Display options
@@ -67,7 +67,7 @@ Examples of use:
Monitor local machine and export stats to a CSV file (standalone mode):
$ glances --export csv --export-csv-file /tmp/glances.csv
- Monitor local machine and export stats to a InfluxDB server with 5s refresh time (standalone mode):
+ Monitor local machine and export stats to a InfluxDB server with 5s refresh rate (standalone mode):
$ glances -t 5 --export influxdb
Start a Glances XML-RPC server (server mode):